@@ -96,14 +96,16 @@ Note that Truecrypt has cross-platform support while LUKS has better Linux-only
 		# fill comboboxentry
 		self.bus = dbus.SystemBus()
 		self.hal_manager = self.bus.get_object('org.freedesktop.Hal', '/org/freedesktop/Hal/Manager')
-		volume_udi_list = self.hal_manager.FindDeviceByCapability ('volume')
+		self.hal_man_iface = dbus.Interface(self.hal_manager, dbus_interface="org.freedesktop.Hal.Manager")
+		volume_udi_list = self.hal_man_iface.FindDeviceByCapability ('volume')
 		for udi in volume_udi_list:
 			volume = self.bus.get_object ('org.freedesktop.Hal', udi)
-			if volume.GetProperty("volume.is_mounted"): # ignore mounted volumes
+			volume_iface = dbus.Interface(volume, 'org.freedesktop.Hal.Device')
+			if volume_iface.GetProperty("volume.is_mounted"): # ignore mounted volumes
 				continue
-			device_file = volume.GetProperty ('block.device')
-			size = volume.GetProperty('volume.size')
-			label = volume.GetProperty('volume.label')
+			device_file = volume_iface.GetProperty ('block.device')
+			size = volume_iface.GetProperty('volume.size')
+			label = volume_iface.GetProperty('volume.label')
 			if label:
 				self.partitionmodel.prepend(("%s" % device_file, "%.2f GiB — %s"%((size/(1024*1024*1024.0)),label), None))
 			else:
@@ -165,7 +167,7 @@ Note that Truecrypt has cross-platform support while LUKS has better Linux-only
 					hb.append_text(i)
 
 			elif dtype == TYPE_LUKS:
-				self.tree.get_widget('e_label').set_text(_("Cipher:"))
+				self.tree.get_widget('e_label').set_text(_("Encryption method:"))
 				self.tree.get_widget('h_label').set_text(_("Key length:"))
 				for i in [ x+'-'+y for y in ['lrw-benbi','xts-plain','cbc-essiv:sha256'] for x in ['aes','serpent'] ]:
 					eb.append_text(i)
@@ -198,9 +200,12 @@ Note that Truecrypt has cross-platform support while LUKS has better Linux-only
 			if self.is_file(self.c_path):
 				size = self.tree.get_widget('sizebutton').get_value()
 			else:
-				udis = self.hal_manager.FindDeviceStringMatch('block.device', self.c_path)
+				udis = self.hal_man_iface.FindDeviceStringMatch('block.device', self.c_path)
 				assert len(udis) == 1, 'Invalid number of results when searching for block.device = %s; udis = %s'%(self.c_path, udis)
-				size = self.bus.get_object ('org.freedesktop.Hal', udis[0]).GetProperty('volume.size')/(1000*1000.0)
+				dbus_hal_volume = self.bus.get_object ('org.freedesktop.Hal', udis[0])
+				size = dbus.Interface(dbus_hal_volume,
+						'org.freedesktop.Hal.Device').GetProperty(
+								'volume.size')/(1000*1000.0)
 				
 
 			str_type = "undefined"
@@ -231,7 +236,7 @@ Note that Truecrypt has cross-platform support while LUKS has better Linux-only
 					tb.insert_with_tags(tb.get_end_iter(), ' '+_("(with keyfile: %s)")%self.tree.get_widget('luks_keyfile').get_filename(), self.bold_tag)
 				else:
 					tb.insert_with_tags(tb.get_end_iter(), ' '+_("(with password)"), self.bold_tag)
-				tb.insert(tb.get_end_iter(),'\n'+_("Cipher:")+" ")
+				tb.insert(tb.get_end_iter(),'\n'+_("Encryption method:")+" ")
 				tb.insert_with_tags(tb.get_end_iter(),eb.get_model().get_value(eb.get_active_iter(), 0),self.bold_tag)
 				tb.insert(tb.get_end_iter(),'\n'+_("Key length:")+" ")
 				tb.insert_with_tags(tb.get_end_iter(),hb.get_model().get_value(hb.get_active_iter(), 0),self.bold_tag)
